@@ -1431,8 +1431,10 @@ class XY(AppForm):
                             print(a)
                             x = a[:, 0]
                             y = a[:, 1]
-                            self.axes.plot(np.unique(x), np.poly1d(np.polyfit(x, y, 1))(np.unique(x)), color='k',
-                                           alpha=0.3)
+
+                            self.axes.plot(x, y, color='red', alpha=0.3)
+                            #self.axes.plot(np.unique(x), np.poly1d(np.polyfit(x, y, 1))(np.unique(x)), color='k', alpha=0.3)
+
                 self.axes.set_xlim(xmin, xmax)
                 self.axes.set_ylim(ymin, ymax)
 
@@ -1492,8 +1494,10 @@ class XY(AppForm):
                         print(a)
                         x = a[:, 0]
                         y = a[:, 1]
-                        self.axes.plot(np.unique(x), np.poly1d(np.polyfit(x, y, 1))(np.unique(x)), color='k',
-                                       alpha=0.3)
+
+                        self.axes.plot(x, y, color='blue', alpha=0.3)
+                        #self.axes.plot(np.unique(x), np.poly1d(np.polyfit(x, y, 1))(np.unique(x)), color='k', alpha=0.3)
+
             self.axes.set_xlim(xmin, xmax)
             self.axes.set_ylim(ymin, ymax)
 
